(authorize {:keys [method uri query headers payload date region service
access-key secret-key debug]})Returns complete authorization header given data of request-to-sign including headers
Returns complete authorization header given data of request-to-sign including headers
(canonical-headers headers)(canonical-request {:keys [method uri query payload headers]})Returns canonical request as string
Returns canonical request as string
(signature {:keys [secret-key short-timestamp region service string-to-sign]})Returns hmac-256 signature given credential scope, secret and string-to-sign
Returns hmac-256 signature given credential scope, secret and string-to-sign
(string-to-sign {:keys [timestamp method uri query payload short-timestamp
region service headers debug]})Returns string to sign given data of request-to-sign
Returns string to sign given data of request-to-sign
(url-encode s)Percent encode the string to put in a URL.
Percent encode the string to put in a URL.
Mapping of AWS zones to S3 endpoints as documented here: http://docs.aws.amazon.com/general/latest/gr/rande.html#s3_region
Mapping of AWS zones to S3 endpoints as documented here: http://docs.aws.amazon.com/general/latest/gr/rande.html#s3_region
(zone->host zone)Maps a zone to the full host name
Maps a zone to the full host name
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |